@@ -48,6 +48,7 @@
 #include <clocale>
 #include <stack>
 #include <cstring>
+#include <sstream>
 #include <libgen.h>
 #include <unistd.h>
 
@@ -184,8 +185,8 @@ void Document::SetFileName (string const &Name, const gchar* mime_type)
 	int j = strlen (m_filename) - 1;
 	while ((i < j) && (m_filename[j] != '.'))
 		j--;
-	if (m_label)
-		g_free (m_label);
+	g_free (m_label);
+	m_label = NULL;
 	char *ext = m_filename + j + 1;
 	list<string> &exts = m_pApp->GetExtensions (m_FileType);
 	list<string>::iterator cur, end = exts.end ();
@@ -541,7 +542,8 @@ void Document::AddBond (Bond* pBond)
 		while (GetDescendant(id) != NULL);
 		pBond->SetId (id);
 	}
-	AddChild (pBond);
+	if (pBond->GetParent () == NULL)
+		AddChild (pBond);
 	Atom *pAtom0 = (Atom*) pBond->GetAtom (0), *pAtom1 = (Atom*) pBond->GetAtom (1);
 	if (m_pView->GetCanvas ()) {
 		pAtom0->UpdateItem ();
@@ -1301,12 +1303,12 @@ double Document::GetYAlign ()
 
 void Document::SetTheme (Theme *theme)
 {
+	if (m_Theme)
+		m_Theme->RemoveClient (this);
 	if (!theme) {
 		m_Theme = NULL;
 		return;
 	}
-	if (m_Theme)
-		m_Theme->RemoveClient (this);
 	m_Theme = theme;
 	m_Theme->AddClient (this);
 	m_BondLength = theme->GetBondLength ();
@@ -1445,11 +1447,55 @@ bool Document::SetProperty (unsigned property, char const *value)
 		if (*end != 0)
 			return false;
 		gcu::Document::SetScale (m_Theme->GetBondLength () / length); 
+		break;
 	}
 	}
 	return true;
 }
 
+std::string Document::GetProperty (unsigned property) const
+{
+	ostringstream res;
+	switch (property) {
+	case GCU_PROP_DOC_FILENAME:
+		res << GetFileName ();
+		break;
+	case GCU_PROP_DOC_MIMETYPE:
+		res << m_FileType;
+		break;
+	case GCU_PROP_DOC_TITLE:
+		res << GetTitle ();
+		break;
+	case GCU_PROP_DOC_COMMENT:
+		res << m_comment;
+		break;
+	case GCU_PROP_DOC_CREATOR:
+		res << m_author;
+		break;
+	case GCU_PROP_DOC_CREATION_TIME: {
+		char buf[16];
+		*buf = 0;
+		g_date_strftime (buf, 16, "%F", &CreationDate);
+		res << buf;
+		break;
+	}
+	case GCU_PROP_DOC_MODIFICATION_TIME: {
+		char buf[16];
+		*buf = 0;
+		g_date_strftime (buf, 16, "%F", &RevisionDate);
+		res << buf;
+		break;
+	}
+	case GCU_PROP_THEME_BOND_LENGTH: {
+		res << m_Theme->GetBondLength ();
+		break;
+	default:
+		return gcu::Document::GetProperty (property);
+	}
+	}
+	return res.str ();
+}
+
 GtkWindow *Document::GetGtkWindow ()
 {
 	return (m_Window)? m_Window->GetWindow (): NULL;
