@@ -27,10 +27,10 @@
 
 namespace gcp {
 	
-gchar const *Color = "black";
-gchar const *DeleteColor = "red";
-gchar const *AddColor = "green";
-gchar const *SelectColor = "cyan";
+GOColor Color = GO_COLOR_BLACK;
+GOColor DeleteColor = GO_COLOR_RED;
+GOColor AddColor = GO_COLOR_GREEN;
+GOColor SelectColor = GO_COLOR_CYAN;
 unsigned MaxStackSize = 0;//infinite size authorized for undo:redo stacks
 bool MergeAtoms = true;
 int CompressionLevel = 0;
