@@ -4,7 +4,7 @@
  * GChemPaint libray
  * settings.h 
  *
- * Copyright (C) 2001-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2009 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -25,8 +25,7 @@
 #ifndef GCHEMPAINT_SETTINGS_H
 #define GCHEMPAINT_SETTINGS_H
 
-#include <glib.h>
-#include <pango/pango.h>
+#include <goffice/goffice.h>
 
 #define ROOTDIR "/apps/gchemutils/paint/settings/"
 #define GCP_CONF_DIR_SETTINGS "paint/settings"
@@ -37,19 +36,19 @@ namespace gcp {
 /*!
 The color used for normal drawing.
 */
-extern const gchar *Color;
+extern GOColor Color;
 /*!
 The color used for objects that are to be deleted.
 */
-extern const gchar *DeleteColor;
+extern GOColor DeleteColor;
 /*!
 The color used for new objects.
 */
-extern const gchar *AddColor;
+extern GOColor AddColor;
 /*!
 The color used for selected objects.
 */
-extern const gchar *SelectColor;
+extern GOColor SelectColor;
 /*!
 The stack size for undo/redo operations. Default is no limit.
 */
@@ -63,6 +62,10 @@ extern bool MergeAtoms;
 XML file compression level.
 */
 extern int CompressionLevel;
+/*!
+Whether the mendeleiv table widget might be detached from the tool box or not.
+*/
+extern bool TearableMendeleiev;
 
 /*!
 Clipboard formats identifiers
