@@ -36,6 +36,7 @@
 #include <gccv/text.h>
 #include <gcu/formula.h>
 #include <gcu/objprops.h>
+#include <gcu/xml-utils.h>
 #include <glib/gi18n-lib.h>
 #include <stdexcept>
 #include <cmath>
@@ -48,17 +49,17 @@ namespace gcp {
 
 Text::Text ():
 	TextObject (TextType),
-	m_Align (PANGO_ALIGN_LEFT),
-	m_Justified (false),
-	m_Anchor (gccv::AnchorLineWest)
+	m_Anchor (gccv::AnchorLineWest),
+	m_Interline (0.),
+	m_Justification (GTK_JUSTIFY_LEFT)
 {
 }
 
 Text::Text (double x, double y):
 	TextObject (x, y, TextType),
-	m_Align (PANGO_ALIGN_LEFT),
-	m_Justified (false),
-	m_Anchor (gccv::AnchorLineWest)
+	m_Anchor (gccv::AnchorLineWest),
+	m_Interline (0.),
+	m_Justification (GTK_JUSTIFY_LEFT)
 {
 }
 
@@ -235,73 +236,112 @@ bool SaveStruct::Save (xmlDocPtr xml, xmlNodePtr node, unsigned &index, string c
 		break;
 	}
 	case gccv::Underline: {
-		PangoUnderline u = static_cast <gccv::UnderlineTextTag *> (m_tag)->GetUnderline ();
+		gccv::TextDecoration u = static_cast <gccv::UnderlineTextTag *> (m_tag)->GetUnderline ();
 		char const *type = NULL;
+		if (u == gccv::TextDecorationNone)
+			break;
 		switch (u) {
-		case PANGO_UNDERLINE_NONE:
-		case PANGO_UNDERLINE_SINGLE:
+		default:
+		case gccv::TextDecorationDefault:
 			break;
-		case PANGO_UNDERLINE_DOUBLE:
-			type = "double";
+		case gccv::TextDecorationHigh:
+			type = "high"; // not really implemented
 			break;
-		case PANGO_UNDERLINE_LOW:
+		case gccv::TextDecorationMedium:
+			type = "medium"; // not really implemented
+			break;
+		case gccv::TextDecorationLow:
 			type = "low";
 			break;
-		case PANGO_UNDERLINE_ERROR:
-			type = "error"; // not really implemented
+		case gccv::TextDecorationDouble:
+			type = "double";
+			break;
+		case gccv::TextDecorationSquiggle:
+			type = "squiggle"; // not really implemented
 			break;
 		}
-		if (u == PANGO_UNDERLINE_NONE)
-			break;
 		child = xmlNewDocNode (xml, NULL, reinterpret_cast <xmlChar const *> ("u"), NULL);
-		if (u != PANGO_UNDERLINE_SINGLE)
+		if (u != gccv::TextDecorationDefault)
 			xmlNewProp (child, reinterpret_cast <xmlChar const *> ("type"), reinterpret_cast <xmlChar const *> (type));
+		WriteColor (child, static_cast <gccv::UnderlineTextTag *> (m_tag)->GetColor ());
 		break;
 	}
-	case gccv::Strikethrough:
-		if (static_cast <gccv::StrikethroughTextTag *> (m_tag)->GetStrikethrough ())
-			child = xmlNewDocNode (xml, NULL, reinterpret_cast <xmlChar const *> ("s"), NULL);
+	case gccv::Overline: { // not really implemented
+		gccv::TextDecoration o = static_cast <gccv::OverlineTextTag *> (m_tag)->GetOverline ();
+		char const *type = NULL;
+		if (o == gccv::TextDecorationNone)
+			break;
+		switch (o) {
+		default:
+		case gccv::TextDecorationDefault:
+			break;
+		case gccv::TextDecorationHigh:
+			type = "high";
+			break;
+		case gccv::TextDecorationMedium:
+			type = "medium";
+			break;
+		case gccv::TextDecorationLow:
+			type = "low";
+			break;
+		case gccv::TextDecorationDouble:
+			type = "double";
+			break;
+		case gccv::TextDecorationSquiggle:
+			type = "squiggle";
+			break;
+		}
+		child = xmlNewDocNode (xml, NULL, reinterpret_cast <xmlChar const *> ("o"), NULL);
+		if (o != gccv::TextDecorationDefault)
+			xmlNewProp (child, reinterpret_cast <xmlChar const *> ("type"), reinterpret_cast <xmlChar const *> (type));
+		WriteColor (child, static_cast <gccv::OverlineTextTag *> (m_tag)->GetColor ());
 		break;
+	}
+	case gccv::Strikethrough: {
+		gccv::TextDecoration s = static_cast <gccv::StrikethroughTextTag *> (m_tag)->GetStrikethrough ();
+		char const *type = NULL;
+		if (s == gccv::TextDecorationNone)
+			break;
+		switch (s) {
+		default:
+		case gccv::TextDecorationDefault:
+			break;
+		case gccv::TextDecorationHigh:
+			type = "high"; // not really implemented
+			break;
+		case gccv::TextDecorationMedium:
+			type = "medium"; // not really implemented
+			break;
+		case gccv::TextDecorationLow:
+			type = "low";
+			break;
+		case gccv::TextDecorationDouble:
+			type = "double";
+			break;
+		case gccv::TextDecorationSquiggle:
+			type = "squiggle"; // not really implemented
+			break;
+		}
+		child = xmlNewDocNode (xml, NULL, reinterpret_cast <xmlChar const *> ("s"), NULL);
+		if (s != gccv::TextDecorationDefault)
+			xmlNewProp (child, reinterpret_cast <xmlChar const *> ("type"), reinterpret_cast <xmlChar const *> (type));
+		WriteColor (child, static_cast <gccv::StrikethroughTextTag *> (m_tag)->GetColor ());
+		break;
+	}
 	case gccv::Foreground: {
 		GOColor color = static_cast <gccv::ForegroundTextTag *> (m_tag)->GetColor ();
-		if (color == RGBA_BLACK)
+		if (color == GO_COLOR_BLACK)
 			break;
 		child = xmlNewDocNode (xml, NULL, reinterpret_cast <xmlChar const *> ("fore"), NULL);
-		char *buf = g_strdup_printf ("%g", DOUBLE_RGBA_R (color));
-		xmlNewProp (child, reinterpret_cast <xmlChar const *> ("red"), reinterpret_cast <xmlChar const *> (buf));
-		g_free (buf);
-		buf = g_strdup_printf ("%g", DOUBLE_RGBA_G (color));
-		xmlNewProp (child, reinterpret_cast <xmlChar const *> ("green"), reinterpret_cast <xmlChar const *> (buf));
-		g_free (buf);
-		buf = g_strdup_printf ("%g", DOUBLE_RGBA_B (color));
-		xmlNewProp (child, reinterpret_cast <xmlChar const *> ("blue"), reinterpret_cast <xmlChar const *> (buf));
-		g_free (buf);
-		if (UINT_RGBA_A (color) != 0xff) {
-			buf = g_strdup_printf ("%g", DOUBLE_RGBA_A (color));
-			xmlNewProp (child, reinterpret_cast <xmlChar const *> ("alpha"), reinterpret_cast <xmlChar const *> (buf));
-			g_free (buf);
-		}
+		WriteColor (child, color);
 		break;
 	}
 	case gccv::Background: {
 		GOColor color = static_cast <gccv::BackgroundTextTag *> (m_tag)->GetColor ();
-		if (color == RGBA_BLACK)
+		if (color == GO_COLOR_BLACK)
 			break;
 		child = xmlNewDocNode (xml, NULL, reinterpret_cast <xmlChar const *> ("back"), NULL);
-		char *buf = g_strdup_printf ("%g", DOUBLE_RGBA_R (color));
-		xmlNewProp (child, reinterpret_cast <xmlChar const *> ("red"), reinterpret_cast <xmlChar const *> (buf));
-		g_free (buf);
-		buf = g_strdup_printf ("%g", DOUBLE_RGBA_G (color));
-		xmlNewProp (child, reinterpret_cast <xmlChar const *> ("green"), reinterpret_cast <xmlChar const *> (buf));
-		g_free (buf);
-		buf = g_strdup_printf ("%g", DOUBLE_RGBA_B (color));
-		xmlNewProp (child, reinterpret_cast <xmlChar const *> ("blue"), reinterpret_cast <xmlChar const *> (buf));
-		g_free (buf);
-		if (UINT_RGBA_A (color) != 0xff) {
-			buf = g_strdup_printf ("%g", DOUBLE_RGBA_A (color));
-			xmlNewProp (child, reinterpret_cast <xmlChar const *> ("alpha"), reinterpret_cast <xmlChar const *> (buf));
-			g_free (buf);
-		}
+		WriteColor (child, color);
 		break;
 	}
 	case gccv::Rise: {
@@ -340,6 +380,10 @@ bool SaveStruct::Save (xmlDocPtr xml, xmlNodePtr node, unsigned &index, string c
 		}
 		break;
 	}
+	case gccv::NewLine:
+		child = xmlNewDocNode (xml, NULL, reinterpret_cast <xmlChar const *> ("br"), NULL);
+		index++;
+		break;
 	default:
 		break;
 	}
@@ -384,7 +428,7 @@ xmlNodePtr Text::Save (xmlDocPtr xml) const
 		return NULL;
 	}
 	switch (m_Anchor) {
-	case gccv::AnchorLineWest:
+	case gccv::AnchorLineEast:
 		xmlNewProp (node, (xmlChar const *) "anchor", (xmlChar const *) "right");
 		break;
 	case gccv::AnchorLine:
@@ -393,10 +437,25 @@ xmlNodePtr Text::Save (xmlDocPtr xml) const
 	default:
 		break;
 	}
-	if (m_Justified)
+	switch (m_Justification) {
+	case GTK_JUSTIFY_FILL:
 		xmlNewProp (node, (xmlChar const *) "justification", (xmlChar const *) "justify");
-	else if (m_Align != PANGO_ALIGN_LEFT)
-		xmlNewProp (node, (xmlChar const *) "justification", (xmlChar const *) ((m_Align == PANGO_ALIGN_RIGHT)? "right": "center"));
+		break;
+	case GTK_JUSTIFY_RIGHT:
+		xmlNewProp (node, (xmlChar const *) "justification", (xmlChar const *) "right");
+		break;
+	case GTK_JUSTIFY_CENTER:
+		xmlNewProp (node, (xmlChar const *) "justification", (xmlChar const *) "center");
+		break;
+	default:
+		break;
+	}
+	if (m_Interline > 0.) {
+		char *buf = g_strdup_printf ("%g", m_Interline);
+		xmlNewProp (node, reinterpret_cast <xmlChar const *> ("interline"), reinterpret_cast <xmlChar *> (buf));
+		g_free (buf);
+		
+	}
 	unsigned i = 0;
 	SaveStruct *head = NULL, *cur;
 	std::list <gccv::TextTag *> const *tags;
@@ -475,13 +534,13 @@ bool Text::Load (xmlNodePtr node)
 	xmlChar *buf = xmlGetProp (node, (xmlChar const *) "justification");
 	if (buf) {
 		if (!strcmp ((char const *) buf, "justify"))
-			m_Justified = true;
+			m_Justification = GTK_JUSTIFY_FILL;
 		else if (!strcmp ((char const *) buf, "right"))
-			m_Justified = PANGO_ALIGN_RIGHT;
+			m_Justification = GTK_JUSTIFY_RIGHT;
 		else if (!strcmp ((char const *) buf, "center"))
-			m_Justified = PANGO_ALIGN_CENTER;
+			m_Justification = GTK_JUSTIFY_CENTER;
 		else
-			m_Justified = PANGO_ALIGN_LEFT;
+			m_Justification = GTK_JUSTIFY_LEFT;
 		xmlFree (buf);
 	}
 	buf = xmlGetProp (node, (xmlChar const *) "anchor");
@@ -494,13 +553,18 @@ bool Text::Load (xmlNodePtr node)
 			m_Anchor = gccv::AnchorLineWest;
 		xmlFree (buf);
 	}
+	buf = xmlGetProp (node, (xmlChar const *) "interline");
+	if (buf) {
+		m_Interline = strtod (reinterpret_cast <char *> (buf), NULL);
+		xmlFree (buf);
+	}
 	xmlNodePtr child;
 	m_bLoading = true;
 	child = node->children;
 	m_buf.clear ();
 	unsigned pos = 0;
 	while (child) {
-		if (!LoadNode (child, pos, 1))
+		if (!LoadNode (child, pos, 0))
 			return false;
 		child = child->next;
 	}
@@ -511,6 +575,8 @@ bool Text::Load (xmlNodePtr node)
 			text->InsertTextTag (m_TagList.front ());
 			m_TagList.pop_front ();
 		}
+		text->SetJustification (m_Justification);
+		text->SetInterline (m_Interline);
 	}
 	m_bLoading = false;
 	return true;
@@ -547,18 +613,30 @@ bool Text::LoadNode (xmlNodePtr node, unsigned &pos, int level, int cur_size)
 		if (!level)
 			return true;
 		buf = (char*) xmlNodeGetContent (node);
+		// search for '\n' because of old GChemPaint versions bug
+		char *cur = buf;
+		while (cur && *cur) {
+			char *nl = strchr (cur, '\n');
+			if (nl) {
+				tag = new gccv::NewLineTextTag ();
+				unsigned index = nl - buf + start;
+				tag->SetStartIndex (index);
+				tag->SetEndIndex (index + 1);
+				m_TagList.push_front (tag);
+				tag = NULL;
+				cur = nl + 1;
+			} else
+				cur = NULL;
+		}
 		if (buf) {
 			pos += strlen (buf);
 			m_buf.insert (start, buf);
 			xmlFree (buf);
 		}
 	} else if (!strcmp ((const char*) node->name, "br")) {
-/* FIXME		m_buf.insert (pos, "\n");
+		tag = new gccv::NewLineTextTag ();
+		m_buf.insert (pos, "\n");
 		pos++;
-		struct limits l;
-		l.start = start;
-		l.length = 1;
-		pango_attr_list_filter (m_AttrList, (PangoAttrFilterFunc) on_insert, &l);*/
 	} else if (!strcmp ((const char*) node->name, "b")) {
 		PangoWeight weight = PANGO_WEIGHT_BOLD;
 		buf = (char*) xmlGetProp(node, (xmlChar*) "weight");
@@ -577,21 +655,57 @@ bool Text::LoadNode (xmlNodePtr node, unsigned &pos, int level, int cur_size)
 		}
 		tag = new gccv::StyleTextTag (style);
 	} else if (!strcmp ((const char*) node->name, "u")) {
-		PangoUnderline underline = PANGO_UNDERLINE_SINGLE;
+		gccv::TextDecoration underline = gccv::TextDecorationDefault;
 		buf = (char*) xmlGetProp(node, (xmlChar*) "type");
 		if (buf) {
 			if (!strcmp (buf, "double"))
-				underline = PANGO_UNDERLINE_DOUBLE;
+				underline = gccv::TextDecorationDouble;
 			else if (!strcmp (buf, "low"))
-				underline = PANGO_UNDERLINE_LOW;
-			else if (!strcmp (buf, "error"))
-				underline = PANGO_UNDERLINE_ERROR;
+				underline = gccv::TextDecorationLow;
+			else if (!strcmp (buf, "medium"))
+				underline = gccv::TextDecorationMedium;
+			else if (!strcmp (buf, "high"))
+				underline = gccv::TextDecorationHigh;
+			else if (!strcmp (buf, "squiggle"))
+				underline = gccv::TextDecorationSquiggle;
 			xmlFree (buf);
 		}
-		tag = new gccv::UnderlineTextTag (underline);
-	} else if (!strcmp ((const char*) node->name, "s"))
-		tag = new gccv::StrikethroughTextTag (true);
-	else if (!strcmp ((const char*) node->name, "sub")) {
+		tag = new gccv::UnderlineTextTag (underline, ReadColor (node));
+	} else if (!strcmp ((const char*) node->name, "o")) {
+		gccv::TextDecoration overline = gccv::TextDecorationDefault;
+		buf = (char*) xmlGetProp(node, (xmlChar*) "type");
+		if (buf) {
+			if (!strcmp (buf, "double"))
+				overline = gccv::TextDecorationDouble;
+			else if (!strcmp (buf, "low"))
+				overline = gccv::TextDecorationLow;
+			else if (!strcmp (buf, "medium"))
+				overline = gccv::TextDecorationMedium;
+			else if (!strcmp (buf, "high"))
+				overline = gccv::TextDecorationHigh;
+			else if (!strcmp (buf, "squiggle"))
+				overline = gccv::TextDecorationSquiggle;
+			xmlFree (buf);
+		}
+		tag = new gccv::OverlineTextTag (overline, ReadColor (node));
+	} else if (!strcmp ((const char*) node->name, "s")) {
+		gccv::TextDecoration strikethrough = gccv::TextDecorationDefault;
+		buf = (char*) xmlGetProp(node, (xmlChar*) "type");
+		if (buf) {
+			if (!strcmp (buf, "double"))
+				strikethrough = gccv::TextDecorationDouble;
+			else if (!strcmp (buf, "low"))
+				strikethrough = gccv::TextDecorationLow;
+			else if (!strcmp (buf, "medium"))
+				strikethrough = gccv::TextDecorationMedium;
+			else if (!strcmp (buf, "high"))
+				strikethrough = gccv::TextDecorationHigh;
+			else if (!strcmp (buf, "squiggle"))
+				strikethrough = gccv::TextDecorationSquiggle;
+			xmlFree (buf);
+		}
+		tag = new gccv::StrikethroughTextTag (strikethrough, ReadColor (node));
+	} else if (!strcmp ((const char*) node->name, "sub")) {
 		buf = (char*) xmlGetProp (node, (xmlChar*) "height");
 		if (buf) {
 			int rise = -strtoul (buf, NULL, 10) * PANGO_SCALE;
@@ -668,25 +782,11 @@ bool Text::LoadNode (xmlNodePtr node, unsigned &pos, int level, int cur_size)
 			stretch = PANGO_STRETCH_ULTRA_EXPANDED;
 		xmlFree (buf);
 		tag = new gccv::StretchTextTag (stretch);
-	} else if (!strcmp ((const char*) node->name, "fore")) {
-		guint16 red, green, blue;
-		buf = (char*) xmlGetProp(node, (xmlChar*) "red");
-		if (!buf)
-			return false;
-		red = (guint16) (strtod (buf, NULL) * 0xffff);
-		xmlFree (buf);
-		buf = (char*) xmlGetProp(node, (xmlChar*) "green");
-		if (!buf)
-			return false;
-		green = (guint16) (strtod (buf, NULL) * 0xffff);
-		xmlFree (buf);
-		buf = (char*) xmlGetProp(node, (xmlChar*) "blue");
-		if (!buf)
-			return false;
-		blue = (guint16) (strtod (buf, NULL) * 0xffff);
-		xmlFree (buf);
-		tag = new gccv::ForegroundTextTag (RGB_TO_UINT (red, green, blue));
-	} else
+	} else if (!strcmp ((const char*) node->name, "fore"))
+		tag = new gccv::ForegroundTextTag (ReadColor (node));
+	else if (!strcmp ((const char*) node->name, "back"))
+		tag = new gccv::BackgroundTextTag (ReadColor (node));
+	else
 		return true;
 	xmlNodePtr child = node->children;
 	while (child) {
@@ -737,10 +837,6 @@ void Text::AddItem ()
 		PangoLayoutIter* iter = pango_layout_get_iter (layout);
 		m_ascent = pango_layout_iter_get_baseline (iter) / PANGO_SCALE;
 		pango_layout_iter_free (iter);
-		if (m_Justified)
-			pango_layout_set_justify (layout, true);
-		else
-			pango_layout_set_alignment (layout, m_Align);
 		PangoRectangle rect;
 		pango_layout_get_extents (layout, NULL, &rect);
 		const_cast <Text *> (this)->m_length = rect.width / PANGO_SCALE;
@@ -750,19 +846,21 @@ void Text::AddItem ()
 	double x = m_x * theme->GetZoomFactor ();
 	double y = m_y * theme->GetZoomFactor ();
 	gccv::Text *text = new gccv::Text (view->GetCanvas ()->GetRoot (), x, y, this);
-	text->SetFillColor ((view->GetData ()->IsSelected (this))? SelectColor: 0);
+	text->SetFillColor (0);
 	text->SetPadding (theme->GetPadding ());
-	text->SetLineColor (0);
+	text->SetLineColor ((view->GetData ()->IsSelected (this))? SelectColor: 0);
 	text->SetLineOffset (view->GetCHeight ());
 	text->SetAnchor (m_Anchor);
 	text->SetFontDescription (desc);
+	text->SetJustification (m_Justification);
+	text->SetInterline (m_Interline);
 	pango_font_description_free (desc);
 	text->SetText (m_buf.c_str ());
 	while (!m_TagList.empty ()) {
 		text->InsertTextTag (m_TagList.front ());
 		m_TagList.pop_front ();
 	}
-	m_Item = text;
+	m_Item = m_TextItem = text;
 }
 
 void Text::UpdateItem ()
@@ -807,7 +905,7 @@ void Text::SetSelected (int state)
 		color = DeleteColor;
 		break;
 	default:
-		color = RGBA_WHITE;
+		color = GO_COLOR_WHITE;
 		break;
 	}
 	dynamic_cast <gccv::LineItem *> (m_Item)->SetLineColor (color);
@@ -869,16 +967,28 @@ bool Text::SetProperty (unsigned property, char const *value)
 		break;
 	case GCU_PROP_TEXT_JUSTIFICATION:
 		if (!strcmp (value, "right"))
-				m_Align = PANGO_ALIGN_RIGHT;
+				m_Justification = GTK_JUSTIFY_RIGHT;
 		else if (!strcmp (value, "left"))
-				m_Align = PANGO_ALIGN_LEFT;
+				m_Justification = GTK_JUSTIFY_LEFT;
 		else if (!strcmp (value, "center"))
-				m_Align = PANGO_ALIGN_CENTER;
+				m_Justification = GTK_JUSTIFY_CENTER;
 		else if (!strcmp (value, "justify"))
-				m_Justified = true;
+				m_Justification = GTK_JUSTIFY_FILL;
 		break;
 	}
 	return true;
 }
 
+void Text::InterlineChanged (double interline)
+{
+	m_Interline = interline;
+	OnChanged (!m_bLoading);
+}
+
+void Text::JustificationChanged (GtkJustification justification)
+{
+	m_Justification = justification;
+	OnChanged (!m_bLoading);
+}
+
 }	//	namespace gcp
