@@ -4,7 +4,7 @@
  * GChemPaint library
  * text.h 
  *
- * Copyright (C) 2002-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2009 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -109,26 +109,21 @@ Loads a portion of a text with a unique set of attributes. \a pos and
 */
 	bool LoadNode (xmlNodePtr node, unsigned &pos, int level = 0, int cur_size = 0);
 /*!
-@param w a GtkWidget.
-
-Adds the representation of the text to the canvas widget.
+Used to add a representation of the text in the view.
 */
-	void Add (GtkWidget* w) const;
+	void AddItem ();
 /*!
-@param w a GtkWidget.
-
-Updates the representation of the text in the canvas widget.
+Used to update the representation of the text in the view.
 */
-	void Update (GtkWidget* w) const;
+	void UpdateItem ();
 /*!
-@param w the GtkWidget inside which the text is displayed.
 @param state the selection state of the text.
 
-Used to set the selection state of text inside the widget.
+Used to set the selection state of text inside.
 The values of state might be gcp::SelStateUnselected, gcp::SelStateSelected,
 gcp::SelStateUpdating, or gcp::SelStateErasing.
 */
-	void SetSelected (GtkWidget* w, int state);
+	void SetSelected (int state);
 /*!
 @param save whether the text should be saved for undo/redo operations.
 
@@ -146,14 +141,6 @@ transformation of its coordinates.
 */
 	void Transform2D (gcu::Matrix2D& m, double x, double y);
 /*!
-@param event a GdkEvent.
-
-Called by the framework during the edition of the text item. It is just called
-to filter out right button clicks.
-@return true for right button clicks to filetr them out, false for other events.
-*/
-	bool OnEvent (GdkEvent *event);
-/*!
 @param x where to store the width of the text.
 @param y where to store the height of the text.
 
@@ -183,45 +170,31 @@ and GCU_PROP_TEXT_JUSTIFICATION.
 @return true if the property could be set, or if the property is not relevant, false otherwise.
 */
 	bool SetProperty (unsigned property, char const *value);
+/*!
+*/
+	void InterlineChanged (double interline);
+/*!
+*/
+	void JustificationChanged (GtkJustification justification);
 
-/*!\fn SetAlign(PangoAlignment Align)
-@param Align the new PangoAlignment for the text.
+/*!\fn SetAnchor(gccv::Anchor Anchor)
+@param Anchor the new gccv::Anchor for the text.
 
-Sets the PangoAlignment for the text. Default is PANGO_ALIGN_LEFT.
-*/
-/*!\fn GetAlign()
-@return the current PangoAlignment for the text instance.
-*/
-/*!fn GetRefAlign()
-@return the current PangoAlignment for the text instance as a reference.
-*/
-GCU_PROP (PangoAlignment, Align)
-/*!\fn SetJustified(bool Justified)
-@param Justified whether the text should be justified.
-
-Sets the justification for the text. Default is false.
-*/
-/*!\fn GetJustified()
-@return the justification for the text.
-*/
-/*!fn GetRefJustified()
-@return the justification for the text as a reference.
-*/
-GCU_PROP (bool, Justified)
-/*!\fn SetAnchor(GtkAnchorType Anchor)
-@param Anchor the new GtkAnchorType for the text.
-
-Sets the GtkAnchorType used for this text. Default is GTK_ANCHOR_W. The vertical
+Sets the gccv::Anchor used for this text. Default is GTK_ANCHOR_W. The vertical
 alignment being based on the base line with an offset equal to the half height of
 a carbon atom symbol using the current document theme.
 */
 /*!\fn GetAnchor()
-@return the GtkAnchorType used for the text.
+@return the gccv::Anchor used for the text.
 */
 /*!fn GetRefAnchor()
-@return the GtkAnchorType used for the text as a reference.
+@return the gccv::Anchor used for the text as a reference.
 */
-GCU_PROP (GtkAnchorType, Anchor)
+GCU_PROP (gccv::Anchor, Anchor)
+
+private:
+	double m_Interline;
+	GtkJustification m_Justification;
 };
 
 }	//	namespace gcp
