@@ -22,30 +22,22 @@
 
 #include "config.h"
 #include "cmd-context.h"
-#ifndef GOFFICE_HAS_GLOBAL_HEADER
-#   include <goffice/app/error-info.h>
-#endif
-#include <gcu/goffice-compat.h>
 #include <gsf/gsf-impl-utils.h>
 #include <stdio.h>
 
-#ifndef GO_TYPE_CMD_CONTEXT
-#   define GO_TYPE_CMD_CONTEXT GO_CMD_CONTEXT_TYPE
-#endif
-
 typedef	GObject GcuCmdContext;
 typedef GObjectClass GcuCmdContextClass;
 
 static void
-gcu_cc_error_error (GOCmdContext *cc, GError *error)
+gcu_cc_error_error (G_GNUC_UNUSED GOCmdContext *cc, GError *error)
 {
 	fprintf (stderr, "Error: %s\n", error->message);
 }
 
 static void
-gcu_cc_error_info (GOCmdContext *cc, ErrorInfo *error)
+gcu_cc_error_info (G_GNUC_UNUSED GOCmdContext *cc, GOErrorInfo *error)
 {
-	error_info_print (error);
+	go_error_info_print (error);
 }
 
 static char *
@@ -62,21 +54,17 @@ gcu_cc_set_sensitive (G_GNUC_UNUSED GOCmdContext *cc,
 }
 
 static void
-#ifdef GOFFICE_USE_DOUBLE
-gcu_cc_progress_set (GOCmdContext *cc, double val)
-#else
-gcu_cc_progress_set (GOCmdContext *cc, gfloat val)
-#endif
+gcu_cc_progress_set (G_GNUC_UNUSED GOCmdContext *cc, G_GNUC_UNUSED gfloat val)
 {
 }
 
 static void
-gcu_cc_progress_message_set (GOCmdContext *cc, gchar const *msg)
+gcu_cc_progress_message_set (G_GNUC_UNUSED GOCmdContext *cc, G_GNUC_UNUSED gchar const *msg)
 {
 }
 
 static void
-gcu_cc_cmd_context_init (GOCmdContextClass *iface)
+gcu_cc_cmd_context_init (G_GNUC_UNUSED GOCmdContextClass *iface)
 {
 	iface->get_password			= gcu_cc_get_password;
 	iface->set_sensitive		= gcu_cc_set_sensitive;
@@ -97,6 +85,6 @@ GOCmdContext *
 gcu_get_cmd_context (void)
 {
 	if (!cc)
-		cc = GO_CMD_CONTEXT (g_object_new (GCU_CMD_CONTEXT_TYPE, NULL));
+		cc = GO_CMD_CONTEXT (g_object_new (GCU_TYPE_CMD_CONTEXT, NULL));
 	return cc;
 }
