@@ -2,7 +2,7 @@
  * Gnome Chemisty Utils
  * chem-viewer.c 
  *
- * Copyright (C) 2005-2009 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005-2008 Jean Bréfort <jean.brefort@normalesup.org>
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
  * published by the Free Software Foundation; either version 2 of the
@@ -30,17 +30,13 @@
 #include <gcp/theme.h>
 #include <gcp/view.h>
 #include <gcp/widgetdata.h>
+#include <gccv/structs.h>
 #include <goffice/goffice.h>
-#ifndef GOFFICE_HAS_GLOBAL_HEADER
-#   include <goffice/app/go-plugin.h>
-#   include <goffice/app/go-plugin-loader-module.h>
-#endif
+#include <goffice/app/go-plugin.h>
+#include <goffice/app/go-plugin-loader-module.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtkmain.h>
 #include <gtk/gtkplug.h>
-#ifdef GOFFICE_IS_0_6
-#	include <libgnomevfs/gnome-vfs.h>
-#endif
 #include <iostream>
 #include <fstream>
 #include <sstream>
@@ -49,10 +45,6 @@
 #include <string>
 #include <cstring>
 
-#ifndef GO_TYPE_PLUGIN_LOADER_MODULE
-#   define GO_TYPE_PLUGIN_LOADER_MODULE GO_PLUGIN_LOADER_MODULE_TYPE
-#endif
-
 using namespace std;
 using namespace gcu;
 
@@ -64,7 +56,7 @@ public:
 	MozPaintApp ();
 	virtual ~MozPaintApp ();
 
-	void OnFileNew (char const *Theme = NULL) {}
+	void OnFileNew (G_GNUC_UNUSED char const *Theme = NULL) {}
 	GtkWindow* GetWindow() {return NULL;}
 };
 
@@ -95,6 +87,7 @@ private:
 	gcp::Document *Doc;
 	map<string, string> Params;
 	MozPaintApp *gcpApp;
+	gcu::Application *App;
 };
 
 ChemComp::ChemComp (void* instance, string& mime_type)
@@ -105,7 +98,6 @@ ChemComp::ChemComp (void* instance, string& mime_type)
 	Plug = NULL;
 	Doc = NULL;
 	gcpApp = NULL;
-	Viewer = NULL;
 }
 
 ChemComp::~ChemComp ()
@@ -118,8 +110,6 @@ ChemComp::~ChemComp ()
 void ChemComp::SetWindow (XID xid)
 {
 	int width, height;
-	if (Viewer)
-		return;
 	if (Xid == xid) {
 		//just resize and redraw
 		gdk_window_get_geometry (Parent, NULL, NULL, &width, &height, NULL);
@@ -133,17 +123,17 @@ void ChemComp::SetWindow (XID xid)
 		gdk_window_get_geometry (Parent, NULL, NULL, &width, &height, NULL);
 		gtk_window_set_default_size (GTK_WINDOW (Plug), width, height);
 		gtk_widget_realize (Plug);
-		XReparentWindow (GDK_WINDOW_XDISPLAY (Plug->window),
-			GDK_WINDOW_XID (Plug->window), xid, 0, 0);
-		XMapWindow (GDK_WINDOW_XDISPLAY (Plug->window),
-			GDK_WINDOW_XID (Plug->window));
-		if (MimeType == "application/x-gcrystal")
+		GdkWindow *window = gtk_widget_get_window (Plug);
+		XReparentWindow (GDK_WINDOW_XDISPLAY (window),
+			GDK_WINDOW_XID (window), xid, 0, 0);
+		XMapWindow (GDK_WINDOW_XDISPLAY (window),
+			GDK_WINDOW_XID (window));
+		if (MimeType == "application/x-gcrystal" || MimeType == "chemical/x-cif")
 			Viewer = gtk_crystal_viewer_new (NULL);
-		else if (MimeType == "application/x-gchempaint") {
+		else if (MimeType == "application/x-gchempaint" || MimeType == "chemical/x-cdx" || MimeType == "chemical/x-cdxml") {
 			if (!gcpApp)
 				gcpApp = new MozPaintApp ();
 			Doc = new gcp::Document (gcpApp, true, NULL);
-			Doc->SetEditable (false);
 			Viewer = Doc->GetView ()->CreateNewWidget ();
 		} else 	if (MimeType == "chemical/x-jcamp-dx")
 			Viewer = gtk_spectrum_viewer_new (NULL);
@@ -156,8 +146,6 @@ void ChemComp::SetWindow (XID xid)
 
 void ChemComp::SetFilename (string& filename)
 {
-	if (Filename.length ())
-		return;
 	Filename = filename;
 	if (MimeType == "application/x-gcrystal") {
 		if (!loaded_radii) {
@@ -169,12 +157,17 @@ void ChemComp::SetFilename (string& filename)
 			return;
 		gtk_crystal_viewer_set_data (GTK_CRYSTAL_VIEWER (Viewer), xml->children);
 		xmlFree (xml);
+/*	} else if (MimeType == "chemical/x-cif") {
+		if (!loaded_radii) {
+			Element::LoadRadii ();
+			loaded_radii = true;
+		}*/
 	} else 	if (MimeType == "application/x-gchempaint") {
 		xmlDocPtr xml = xmlParseFile (filename.c_str ());
 		if (!xml || !xml->children || strcmp ((char*) xml->children->name, "chemistry"))
 			return;
 		Doc->Load (xml->children);
-		ArtDRect r;
+		gccv::Rect r;
 		gcp::WidgetData *pData = (gcp::WidgetData*) g_object_get_data (G_OBJECT (Viewer), "data");
 		pData->GetObjectBounds (Doc, &r);
 		gcp::Theme *pTheme = Doc->GetTheme ();
@@ -183,6 +176,10 @@ void ChemComp::SetFilename (string& filename)
 		Doc->GetView ()->Update (Doc);
 		pData->GetObjectBounds (Doc, &r);
 		xmlFree (xml);
+	} else if (MimeType == "chemical/x-cdx" || MimeType == "chemical/x-cdxml") {
+		char *uri = g_filename_to_uri (filename.c_str (), NULL, NULL);
+		gcpApp->Load (uri, MimeType.c_str (), Doc);
+		g_free (uri);
 	} else 	if (MimeType == "chemical/x-jcamp-dx") {
 		char *uri = g_filename_to_uri (filename.c_str (), NULL, NULL);
 		gtk_spectrum_viewer_set_uri (GTK_SPECTRUM_VIEWER (Viewer), uri);
@@ -211,7 +208,7 @@ GIOChannel *in_channel;
 map<void*, ChemComp*> components;
 
 static gboolean
-io_func (GIOChannel *source, GIOCondition condition, gpointer data)
+io_func (GIOChannel *source, G_GNUC_UNUSED GIOCondition condition, G_GNUC_UNUSED gpointer data)
 {
 	string buf, strinst;
 	void *instance;
@@ -304,12 +301,6 @@ int main (int argc, char *argv[])
 	GError *error = NULL;
 
 	gtk_init (&argc, &argv);
-#ifdef GOFFICE_IS_0_6
-	if (!gnome_vfs_init ()) {
-		cerr << "Could not initialize GnomeVFS\n" << endl;
-		return 1;
-	}
-#endif
 	libgoffice_init ();
 	go_plugins_init (NULL, NULL, NULL, NULL, TRUE, GO_TYPE_PLUGIN_LOADER_MODULE);
 	in_channel = g_io_channel_unix_new (fileno (stdin));
