@@ -29,6 +29,7 @@
 
 namespace gcp {
 	class Atom;
+	class Bond;
 	class Operation;
 }
 
@@ -56,7 +57,6 @@ protected:
 protected:
 	double m_dAngle;
 	gcp::Atom* m_pAtom;
-	GnomeCanvasPoints *points;
 	unsigned char BondOrder;
 
 private:
