@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * programs/gchemtable-curve.cc 
  *
- * Copyright (C) 2005-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005-2009 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -29,25 +29,6 @@
 #include <gcu/chemistry.h>
 #include <gcu/element.h>
 #include <gcu/print-setup-dlg.h>
-#ifndef GOFFICE_HAS_GLOBAL_HEADER
-#   include <goffice/data/go-data-simple.h>
-#   include <goffice/gtk/go-graph-widget.h>
-#   include <goffice/gtk/goffice-gtk.h>
-#   include <goffice/graph/gog-axis.h>
-#   include <goffice/graph/gog-data-allocator.h>
-#   include <goffice/graph/gog-data-set.h>
-#   include <goffice/graph/gog-guru.h>
-#   include <goffice/graph/gog-label.h>
-#   include <goffice/graph/gog-object.h>
-#   include <goffice/graph/gog-object-xml.h>
-#   include <goffice/graph/gog-plot.h>
-#   include <goffice/graph/gog-series.h>
-#   include <goffice/math/go-math.h>
-#   include <goffice/utils/go-locale.h>
-#   include <goffice/utils/go-line.h>
-#   include <goffice/utils/go-image.h>
-#   include <goffice/utils/go-marker.h>
-#endif
 #include <gsf/gsf-input-memory.h>
 #include <gsf/gsf-output-memory.h>
 #include <gsf/gsf-output-gio.h>
@@ -55,11 +36,6 @@
 #include <map>
 #include <cstring>
 
-#ifndef GOG_TYPE_LABEL
-#   define GOG_TYPE_LABEL GOG_LABEL_TYPE
-#   define GOG_IS_GRAPH IS_GOG_GRAPH
-#endif
-
 using namespace gcu;
 using namespace std;
 
@@ -77,7 +53,7 @@ void on_show_curve (GObject *obj, char const* name)
 		curves[name] = new GChemTableCurve (App, name);
 }
 
-static void on_get_data (GtkClipboard *clipboard, GtkSelectionData *selection_data,  guint info, GogGraph *graph)
+static void on_get_data (G_GNUC_UNUSED GtkClipboard *clipboard, GtkSelectionData *selection_data,  guint info, GogGraph *graph)
 {
 	guchar *buffer = NULL;
 	char *format = NULL;
@@ -101,11 +77,7 @@ static void on_get_data (GtkClipboard *clipboard, GtkSelectionData *selection_da
 			go_locale_untranslated_booleans ();
 		
 			xout = gsf_xml_out_new (output);
-#ifdef HAVE_GO_DATA_SERIALIZE
 			gog_object_write_xml_sax (GOG_OBJECT (graph), xout, NULL);
-#else
-			gog_object_write_xml_sax (GOG_OBJECT (graph), xout);
-#endif
 			g_object_unref (xout);
 		
 			/* go_setlocale restores bools to locale translation */
@@ -136,13 +108,13 @@ static void on_get_data (GtkClipboard *clipboard, GtkSelectionData *selection_da
 		g_object_unref (output);
 		g_free (format);
 		gtk_selection_data_set (selection_data,
-					selection_data->target, 8,
+					gtk_selection_data_get_target (selection_data), 8,
 					(guchar *) buffer, osize);
 		g_free (buffer);
 	}
 }
 
-void on_clear_data(GtkClipboard *clipboard, GogGraph *graph)
+void on_clear_data(G_GNUC_UNUSED GtkClipboard *clipboard, GogGraph *graph)
 {
 	g_object_unref (graph);
 }
@@ -154,78 +126,78 @@ static GtkTargetEntry const targets[] = {
 	{(char *) "image/png", 0, 3}
 };
 
-static void on_copy (GtkWidget *widget, GChemTableCurve *curve)
+static void on_copy (G_GNUC_UNUSED GtkWidget *widget, GChemTableCurve *curve)
 {
 	curve->OnCopy ();
 }
 
-static void on_file_save_as_image(GtkWidget* widget, GChemTableCurve *curve)
+static void on_file_save_as_image(G_GNUC_UNUSED GtkWidget* widget, GChemTableCurve *curve)
 {
 	curve->GetApplication ()->OnSaveAsImage (curve);
 }
 
-static void on_print (GtkWidget *widget, GChemTableCurve *curve)
+static void on_print (G_GNUC_UNUSED GtkWidget *widget, GChemTableCurve *curve)
 {
 	curve->Print (false);
 }
 
-static void on_print_preview (GtkWidget *widget, GChemTableCurve *curve)
+static void on_print_preview (G_GNUC_UNUSED GtkWidget *widget, GChemTableCurve *curve)
 {
 	curve->Print (true);
 }
 
-static void on_page_setup (GtkWidget *widget, GChemTableCurve *curve)
+static void on_page_setup (G_GNUC_UNUSED GtkWidget *widget, GChemTableCurve *curve)
 {
 	curve->OnPageSetup ();
 }
 
-void on_properties (GtkWidget *widget, GChemTableCurve *curve)
+void on_properties (G_GNUC_UNUSED GtkWidget *widget, GChemTableCurve *curve)
 {
 	curve->OnProperties ();
 }
 
-static void on_close (GtkWidget *widget, GChemTableCurve *curve)
+static void on_close (G_GNUC_UNUSED GtkWidget *widget, GChemTableCurve *curve)
 {
 	curve->Destroy ();
 }
 
-static void on_help (GtkWidget *widget, GChemTableCurve *curve)
+static void on_help (G_GNUC_UNUSED GtkWidget *widget, GChemTableCurve *curve)
 {
 	curve->GetApplication ()->OnHelp ();
 }
 
-static void on_curve_help (GtkWidget *widget, GChemTableCurve *curve)
+static void on_curve_help (G_GNUC_UNUSED GtkWidget *widget, GChemTableCurve *curve)
 {
 	curve->Help ();
 }
 
-static void on_web (GtkWidget *widget, GChemTableCurve *curve)
+static void on_web (G_GNUC_UNUSED GtkWidget *widget, GChemTableCurve *curve)
 {
 	curve->GetApplication ()->OnWeb ();
 }
 
-static void on_live_assistance (GtkWidget *widget, GChemTableCurve *curve)
+static void on_live_assistance (G_GNUC_UNUSED GtkWidget *widget, GChemTableCurve *curve)
 {
 	curve->GetApplication ()->OnLiveAssistance ();
 }
 
-static void on_mail (GtkWidget *widget, GChemTableCurve *curve)
+static void on_mail (G_GNUC_UNUSED GtkWidget *widget, GChemTableCurve *curve)
 {
 	curve->GetApplication ()->OnMail ();
 }
 
-static void on_bug (GtkWidget *widget, GChemTableCurve *curve)
+static void on_bug (G_GNUC_UNUSED GtkWidget *widget, GChemTableCurve *curve)
 {
 	curve->GetApplication ()->OnBug ();
 }
 
-static void on_about (GtkWidget *widget, GChemTableCurve *curve)
+static void on_about (G_GNUC_UNUSED GtkWidget *widget, GChemTableCurve *curve)
 {
 	curve->GetApplication ()->OnAbout ();
 }
 
 static GtkActionEntry entries[] = {
-  { "FileMenu", NULL, N_("_File") },
+  { "FileMenu", NULL, N_("_File"), NULL, NULL, NULL },
 	  { "SaveAsImage", GTK_STOCK_SAVE_AS, N_("Save As _Image..."), "<control>I",
 		  N_("Save the current file as an image"), G_CALLBACK (on_file_save_as_image) },
 	  { "PageSetup", NULL, N_("Page Set_up..."), NULL,
@@ -240,10 +212,10 @@ static GtkActionEntry entries[] = {
 		  N_("Close the current file"), G_CALLBACK (on_close) },
 	  { "Quit", GTK_STOCK_QUIT, N_("_Quit"), "<control>Q",
 		  N_("Quit GChemTable"), G_CALLBACK (gtk_main_quit) },
-  { "EditMenu", NULL, N_("_Edit") },
+  { "EditMenu", NULL, N_("_Edit"), NULL, NULL, NULL },
 	  { "Copy", GTK_STOCK_COPY, N_("_Copy"), "<control>C",
 		  N_("Copy the selection"), G_CALLBACK (on_copy) },
-  { "HelpMenu", NULL, N_("_Help") },
+  { "HelpMenu", NULL, N_("_Help"), NULL, NULL, NULL },
 	  { "Help", GTK_STOCK_HELP, N_("_Contents"), "F1",
 		  N_("View help for the Periodic Table"), G_CALLBACK (on_help) },
 	  { "CurveHelp", GTK_STOCK_HELP, N_("_Help"), "<control>F1",
@@ -291,11 +263,11 @@ static const char *ui_description =
 "</ui>";
 
 GChemTableCurve::GChemTableCurve (GChemTableApp *App, char const *name):
-	Dialog (App, GLADEDIR"/curve.glade", "curvedlg", App),
+	Dialog (App, UIDIR"/curve.ui", "curvedlg", GETTEXT_PACKAGE, App),
 	Printable (),
 	m_Guru (NULL)
 {
-	m_GraphBox = glade_xml_get_widget (xml, "vbox1");
+	m_GraphBox = GetWidget ("vbox1");
 	GtkUIManager *ui_manager = gtk_ui_manager_new ();
 	GtkActionGroup *action_group = gtk_action_group_new ("MenuActions");
 	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
@@ -312,6 +284,7 @@ GChemTableCurve::GChemTableCurve (GChemTableApp *App, char const *name):
 	GtkWidget *bar = gtk_ui_manager_get_widget (ui_manager, "/MainMenu");
 	gtk_box_pack_start (GTK_BOX (m_GraphBox), bar, FALSE, FALSE, 0);
 	m_GraphWidget = go_graph_widget_new (NULL);
+	g_signal_connect_swapped (m_GraphWidget, "size-allocate", G_CALLBACK (GChemTableCurve::OnSize), this);
 	gtk_widget_set_size_request (m_GraphWidget, 400, 250);
 	gtk_widget_show (m_GraphWidget);
 	gtk_box_pack_end (GTK_BOX (m_GraphBox), m_GraphWidget, TRUE, TRUE, 0);
@@ -458,7 +431,7 @@ GChemTableCurve::~GChemTableCurve ()
 	curves.erase (m_Name);
 }
 
-void GChemTableCurve::DoPrint (GtkPrintOperation *print, GtkPrintContext *context) const
+void GChemTableCurve::DoPrint (G_GNUC_UNUSED GtkPrintOperation *print, GtkPrintContext *context, G_GNUC_UNUSED int page) const
 {
 	cairo_t *cr;
 	gdouble width, height;
@@ -468,8 +441,8 @@ void GChemTableCurve::DoPrint (GtkPrintOperation *print, GtkPrintContext *contex
 	height = gtk_print_context_get_height (context);
 
 	int w, h; // size in points
-	w = m_GraphWidget->allocation.width;
-	h = m_GraphWidget->allocation.height;
+	w = m_GraphWidth;
+	h = m_GraphHeight;
 	switch (GetScaleType ()) {
 	case GCU_PRINT_SCALE_NONE:
 		break;
@@ -535,7 +508,7 @@ on_guru_help (Application *app)
 
 void GChemTableCurve::OnProperties ()
 {
-	GctControlGUI *tcg = GCT_CONTROL_GUI (g_object_new (GCT_CONTROL_GUI_TYPE, NULL));
+	GctControlGUI *tcg = GCT_CONTROL_GUI (g_object_new (GCT_TYPE_CONTROL_GUI, NULL));
 	gct_control_gui_set_owner (tcg, this);
 	GClosure *closure = g_cclosure_new (G_CALLBACK (on_update_graph), tcg,
 					(GClosureNotify) graph_user_config_free_data);
@@ -572,3 +545,9 @@ void GChemTableCurve::SaveAsImage (string const &filename, char const *mime_type
 	gog_graph_export_image (graph, format, output, -1., -1.);
 	g_object_unref (graph);
 }
+
+void GChemTableCurve::OnSize (GChemTableCurve *curve, GtkAllocation *allocation)
+{
+	curve->m_GraphWidth = allocation->width;
+	curve->m_GraphHeight = allocation->height;
+}
